@@ -1,11 +1,11 @@
 #include "bashfest.h"
 #include "stdlib.h"
 
-void lpp_putsine (float *arr, int len);
-float lpp_boundrand(float min, float max);
+void lpp_putsine (t_float *arr, int len);
+t_float lpp_boundrand(t_float min, t_float max);
 
 
-void lpp_putsine (float *arr, int len)
+void lpp_putsine (t_float *arr, int len)
 {
     int i;
     double twopi;
@@ -16,13 +16,13 @@ void lpp_putsine (float *arr, int len)
     }
 }
 
-float lpp_boundrand(float min, float max)
+t_float lpp_boundrand(t_float min, t_float max)
 {
-    return min + (max-min) * ((float)rand()/MY_MAX);
+    return min + (max-min) * ((t_float)rand()/MY_MAX);
 }
 
 
-void lpp_mycombset(float loopt,float rvt,int init,float *a,float srate)
+void lpp_mycombset(t_float loopt,t_float rvt,int init,t_float *a,t_float srate)
 {
     int j;
     
@@ -35,9 +35,9 @@ void lpp_mycombset(float loopt,float rvt,int init,float *a,float srate)
     }
 }
 
-float lpp_mycomb(float samp,float *a)
+t_float lpp_mycomb(t_float samp,t_float *a)
 {
-    float temp,*aptr;
+    t_float temp,*aptr;
     if ( a[2] >= (int) a[0])
         a[2] = 3;
     aptr = a + (int)a[2];
@@ -47,9 +47,9 @@ float lpp_mycomb(float samp,float *a)
     return(temp);
 }
 
-void lpp_setweights(float *a, int len)
+void lpp_setweights(t_float *a, int len)
 {
-    float sum = 0.0;
+    t_float sum = 0.0;
     int i;
     for(i=0;i<len;i++)
     sum += a[i];
@@ -62,9 +62,9 @@ void lpp_setweights(float *a, int len)
     a[i] += a[i-1];
 }
 
-void  lpp_delset2(float *a,int *l,float xmax, float srate)
+void  lpp_delset2(t_float *a,int *l,t_float xmax, t_float srate)
 {
-    /* delay initialization.  a is address of float array, l is size-2 int
+    /* delay initialization.  a is address of t_float array, l is size-2 int
      * array for bookkeeping variables, xmax, is maximum expected delay */
     
     int i;
@@ -73,22 +73,22 @@ void  lpp_delset2(float *a,int *l,float xmax, float srate)
     for(i = 0; i < *(l+1); i++) *(a+i) = 0;
 }
 
-void lpp_delput2(float x,float *a,int *l)
+void lpp_delput2(t_float x,t_float *a,int *l)
 {
     
-    /* put value in delay line. See delset. x is float */
+    /* put value in delay line. See delset. x is t_float */
     
     *(a + (*l)++) = x;
     if(*(l) >= *(l+1)) *l -= *(l+1);
 }
 
-float lpp_dliget2(float *a,float wait,int *l,float srate)
+t_float lpp_dliget2(t_float *a,t_float wait,int *l,t_float srate)
 {
     /* get interpolated value from delay line, wait seconds old */
     register int im1;
-    float x = wait * srate;
+    t_float x = wait * srate;
     register int i = x;
-    float frac = x - i;
+    t_float frac = x - i;
     i = *l - i;
     im1 = i - 1;
     if(i <= 0) {
@@ -99,11 +99,11 @@ float lpp_dliget2(float *a,float wait,int *l,float srate)
     return(*(a+i) + frac * (*(a+im1) - *(a+i)));
 }
 
-void lpp_butterLopass( float *in, float *out, float cutoff, int frames, int channels, float srate)
+void lpp_butterLopass( t_float *in, t_float *out, t_float cutoff, int frames, int channels, t_float srate)
 
 {
     int channel_to_compute;
-    float data[8];
+    t_float data[8];
     
     for( channel_to_compute = 0; channel_to_compute < channels; channel_to_compute++) {
         lpp_butset( data );
@@ -113,10 +113,10 @@ void lpp_butterLopass( float *in, float *out, float cutoff, int frames, int chan
     
 }
 
-void lpp_butterBandpass(float *in, float *out, float center, float bandwidth, int frames,int  channels, float srate)
+void lpp_butterBandpass(t_float *in, t_float *out, t_float center, t_float bandwidth, int frames,int  channels, t_float srate)
 {
     int channel_to_compute;
-    float data[8];
+    t_float data[8];
     
     for( channel_to_compute = 0; channel_to_compute < channels; channel_to_compute++) {
         lpp_butset( data );
@@ -127,10 +127,10 @@ void lpp_butterBandpass(float *in, float *out, float center, float bandwidth, in
 }
 
 
-void lpp_butterHipass(float *in, float *out, float cutoff, int frames,int channels, float srate)
+void lpp_butterHipass(t_float *in, t_float *out, t_float cutoff, int frames,int channels, t_float srate)
 {
     int channel_to_compute;
-    float data[8];
+    t_float data[8];
     
     for( channel_to_compute = 0; channel_to_compute < channels; channel_to_compute++) {
         lpp_butset( data );
@@ -140,14 +140,14 @@ void lpp_butterHipass(float *in, float *out, float cutoff, int frames,int channe
     
 }
 
-void lpp_butset(float *a)
+void lpp_butset(t_float *a)
 {
     a[6] = a[7] = 0.0;
 }
 
-void lpp_lobut(float *a, float cutoff,float SR)
+void lpp_lobut(t_float *a, t_float cutoff,t_float SR)
 {
-    register float   c;
+    register t_float   c;
     
     c = 1.0 / tan( PI * cutoff / SR);
     a[1] = 1.0 / ( 1.0 + ROOT2 * c + c * c);
@@ -159,10 +159,10 @@ void lpp_lobut(float *a, float cutoff,float SR)
     
 }
 
-void lpp_hibut(float *a, float cutoff, float SR)
+void lpp_hibut(t_float *a, t_float cutoff, t_float SR)
 {
     
-    register float  c;
+    register t_float  c;
     
     c = tan( PI * cutoff / SR);
     a[1] = 1.0 / ( 1.0 + ROOT2 * c + c * c);
@@ -173,9 +173,9 @@ void lpp_hibut(float *a, float cutoff, float SR)
     
 }
 
-void lpp_bpbut(float *a, float formant, float bandwidth,float  SR)
+void lpp_bpbut(t_float *a, t_float formant, t_float bandwidth,t_float  SR)
 {
-    register float  c, d;
+    register t_float  c, d;
     
     c = 1.0 / tan( PI * bandwidth / SR);
     d = 2.0 * cos( 2.0 * PI * formant / SR);
@@ -188,11 +188,11 @@ void lpp_bpbut(float *a, float formant, float bandwidth,float  SR)
 }
 /* in array can == out array */
 
-void lpp_butter_filter(float *in,float *out,float *a, int frames, int channels, int channel)
+void lpp_butter_filter(t_float *in,t_float *out,t_float *a, int frames, int channels, int channel)
 {
     
     int i;
-    float t ,y ;
+    t_float t ,y ;
     
     for( i = channel ; i < frames * channels; i+= channels )
     {
@@ -204,10 +204,10 @@ void lpp_butter_filter(float *in,float *out,float *a, int frames, int channels,
     }
 }
 
-void lpp_rsnset2(float cf,float bw,float scl,float xinit,float *a,float srate)
+void lpp_rsnset2(t_float cf,t_float bw,t_float scl,t_float xinit,t_float *a,t_float srate)
 {
     //  double exp(),cos(),sqrt();
-    float c,temp;
+    t_float c,temp;
     if(!xinit) {
         a[4] = 0;
         a[3] = 0;
@@ -221,18 +221,18 @@ void lpp_rsnset2(float cf,float bw,float scl,float xinit,float *a,float srate)
     if(!scl) a[0] = temp*sqrt(1.-a[1]*a[1]/(4.*a[2]));
 }
 
-float lpp_reson(float x,float *a)
+t_float lpp_reson(t_float x,t_float *a)
 {
-    float temp;
+    t_float temp;
     temp = *a * x + *(a+1) * *(a+3) - *(a+2) * *(a+4);
     *(a+4) = *(a+3);
     *(a+3) = temp;
     return(temp);
 }
 
-float lpp_allpass(float samp,float *a)
+t_float lpp_allpass(t_float samp,t_float *a)
 {
-    float temp,*aptr;
+    t_float temp,*aptr;
     if ( a[STARTM1] >= (int) a[0]) a[STARTM1] = START;
     aptr = a + (int)a[STARTM1];
     a[STARTM1] ++;
@@ -241,7 +241,7 @@ float lpp_allpass(float samp,float *a)
     return(temp - a[1] * *aptr);
 }
 
-void lpp_init_reverb_data(float *a)
+void lpp_init_reverb_data(t_float *a)
 {
     a[0] = 2;
     a[1] = -0.61043329;
@@ -255,24 +255,24 @@ void lpp_init_reverb_data(float *a)
     a[9] = 0.035888535;
 }
 
-void lpp_reverb1me(float *in, float *out, int inFrames, int out_frames, int nchans,
-                   int channel, float revtime, float dry, t_bashfest *x)
+void lpp_reverb1me(t_float *in, t_float *out, int inFrames, int out_frames, int nchans,
+                   int channel, t_float revtime, t_float dry, t_bashfest *x)
 {
-    float dels[4];// stick into main structure
-    float **alpo = x->mini_delay ;
-    float a1,a2,a3,a4;
+    t_float dels[4];// stick into main structure
+    t_float **alpo = x->mini_delay ;
+    t_float a1,a2,a3,a4;
     int i;
     //  int alsmp ;
-    float *fltdata = x->reverb_ellipse_data;
+    t_float *fltdata = x->reverb_ellipse_data;
     
     int nsects;
-    float xnorm;
+    t_float xnorm;
     LSTRUCT *eel = x->eel;
     
-    float wet;
-    //  float max;
-    float srate = x->sr;
-    //  float max_del = x->max_mini_delay ;
+    t_float wet;
+    //  t_float max;
+    t_float srate = x->sr;
+    //  t_float max_del = x->max_mini_delay ;
     
     wet = cos(1.570796 * dry);
     dry = sin(1.570796 * dry);
@@ -312,23 +312,23 @@ void lpp_reverb1me(float *in, float *out, int inFrames, int out_frames, int ncha
     
 }
 
-void lpp_feed1(float *inbuf, float *outbuf, int in_frames, int out_frames,int channels, float *functab1,
-               float *functab2,float *functab3,float *functab4,int funclen,
-               float duration, float maxDelay, t_bashfest *x)
+void lpp_feed1(t_float *inbuf, t_float *outbuf, int in_frames, int out_frames,int channels, t_float *functab1,
+               t_float *functab2,t_float *functab3,t_float *functab4,int funclen,
+               t_float duration, t_float maxDelay, t_bashfest *x)
 {
     int i;
-    float srate = x->sr;
-    float *delayLine1a = x->mini_delay[0];
-    float *delayLine2a = x->mini_delay[1];
-    float *delayLine1b = x->mini_delay[2];
-    float *delayLine2b = x->mini_delay[3];
+    t_float srate = x->sr;
+    t_float *delayLine1a = x->mini_delay[0];
+    t_float *delayLine2a = x->mini_delay[1];
+    t_float *delayLine1b = x->mini_delay[2];
+    t_float *delayLine2b = x->mini_delay[3];
     int dv1a[2], dv2a[2];   /* cmix bookkeeping */
     int dv1b[2], dv2b[2];   /* cmix bookkeeping */
-    float delsamp1a=0, delsamp2a=0 ;
-    float delsamp1b=0, delsamp2b=0 ;
-    float delay1, delay2, feedback1, feedback2;
-    float funcSi, funcPhs;
-    float putsamp;
+    t_float delsamp1a=0, delsamp2a=0 ;
+    t_float delsamp1b=0, delsamp2b=0 ;
+    t_float delay1, delay2, feedback1, feedback2;
+    t_float funcSi, funcPhs;
+    t_float putsamp;
     
     /***************************/
     
@@ -336,7 +336,7 @@ void lpp_feed1(float *inbuf, float *outbuf, int in_frames, int out_frames,int ch
     
     // read once during note
     
-    funcSi = ((float) funclen / srate) / duration ;
+    funcSi = ((t_float) funclen / srate) / duration ;
     
     
     lpp_delset2(delayLine1a, dv1a, maxDelay,srate);
@@ -357,7 +357,7 @@ void lpp_feed1(float *inbuf, float *outbuf, int in_frames, int out_frames,int ch
         feedback2 = functab4[ (int) funcPhs ];
         
         funcPhs += funcSi;
-        if( funcPhs >= (float) funclen )
+        if( funcPhs >= (t_float) funclen )
             funcPhs = 0;
         
         putsamp = i < in_frames * channels ? inbuf[i] + delsamp1a*feedback1 : 0.0;
@@ -386,18 +386,18 @@ void lpp_feed1(float *inbuf, float *outbuf, int in_frames, int out_frames,int ch
     }
 }
 
-void lpp_setflamfunc1(float *arr, int flen)
+void lpp_setflamfunc1(t_float *arr, int flen)
 {
     int i;
-    float x;
+    t_float x;
     for ( i = 0; i < flen; i++) {
-        x = (float)i / (float) flen ;
+        x = (t_float)i / (t_float) flen ;
         *(arr + i) = ((x - 1) / (x + 1)) * -1.  ;
     }
 }
 
 
-void lpp_setExpFlamFunc(float *arr, int flen, float v1,float v2,float alpha)
+void lpp_setExpFlamFunc(t_float *arr, int flen, t_float v1,t_float v2,t_float alpha)
 {
     int i;
     
@@ -405,23 +405,23 @@ void lpp_setExpFlamFunc(float *arr, int flen, float v1,float v2,float alpha)
         alpha = .00000001 ;
     
     for ( i = 0; i < flen; i++) {
-        *(arr + i) = v1 + (v2-v1) * ((1-exp((float)i*alpha/((float)flen-1.)))/(1-exp(alpha)));
+        *(arr + i) = v1 + (v2-v1) * ((1-exp((t_float)i*alpha/((t_float)flen-1.)))/(1-exp(alpha)));
     }
 }
 
-void lpp_funcgen1(float *outArray, int outlen, float duration, float outMin, float outMax,
-                  float speed1, float speed2, float gain1, float gain2, float *phs1, float *phs2,
-                  float *sine, int sinelen)
+void lpp_funcgen1(t_float *outArray, int outlen, t_float duration, t_float outMin, t_float outMax,
+                  t_float speed1, t_float speed2, t_float gain1, t_float gain2, t_float *phs1, t_float *phs2,
+                  t_float *sine, int sinelen)
 {
-    float si1, si2;
-    float localSR;
+    t_float si1, si2;
+    t_float localSR;
     int i;
     
-    localSR = duration * (float) outlen ;
-    *phs1 *= (float) sinelen;
-    *phs2 *= (float) sinelen;
-    si1 = ((float)sinelen/localSR)  * speed1;
-    si2 = ((float)sinelen/localSR)  * speed2;
+    localSR = duration * (t_float) outlen ;
+    *phs1 *= (t_float) sinelen;
+    *phs2 *= (t_float) sinelen;
+    si1 = ((t_float)sinelen/localSR)  * speed1;
+    si2 = ((t_float)sinelen/localSR)  * speed2;
     
     for( i = 0; i < outlen; i++ ) {
         *(outArray + i) = lpp_oscil(gain1, si1, sine, sinelen, phs1) ;
@@ -431,11 +431,11 @@ void lpp_funcgen1(float *outArray, int outlen, float duration, float outMin, flo
 }
 
 
-void lpp_normtab(float *inarr,float *outarr, float min, float max, int len)
+void lpp_normtab(t_float *inarr,t_float *outarr, t_float min, t_float max, int len)
 {
     int i;
     
-    float imin=9999999999., imax=-9999999999.;
+    t_float imin=9999999999., imax=-9999999999.;
     
     for(i = 0; i < len ; i++) {
         if( imin > inarr[i] )
@@ -447,7 +447,7 @@ void lpp_normtab(float *inarr,float *outarr, float min, float max, int len)
     outarr[i] = lpp_mapp(inarr[i], imin, imax, min, max);
 }
 
-float lpp_mapp(float in,float imin,float imax,float omin,float omax)
+t_float lpp_mapp(t_float in,t_float imin,t_float imax,t_float omin,t_float omax)
 {
     if( imax == 0.0 )
     {
@@ -456,7 +456,7 @@ float lpp_mapp(float in,float imin,float imax,float omin,float omax)
     return( omin+((omax-omin)*((in-imin)/(imax-imin))) );
 }
 
-float lpp_oscil(float amp,float si,float *farray,int len,float *phs)
+t_float lpp_oscil(t_float amp,t_float si,t_float *farray,int len,t_float *phs)
 {
     register int i =  *phs;
     *phs += si;
@@ -465,15 +465,15 @@ float lpp_oscil(float amp,float si,float *farray,int len,float *phs)
     return(*(farray+i) * amp);
 }
 
-void lpp_killdc( float *inbuf, int in_frames, int channels, t_bashfest *x)
+void lpp_killdc( t_float *inbuf, int in_frames, int channels, t_bashfest *x)
 {
     int i,j=1;
     LSTRUCT *eel = x->eel;
     int nsects;
-    float xnorm;
-    float *dcflt = x->dcflt;
+    t_float xnorm;
+    t_float *dcflt = x->dcflt;
     
-    /* float dcflt[64] =
+    /* t_float dcflt[64] =
      {3, -1.9999924    , -1.9992482    ,  1.0000000
      ,  .99928019    ,
      -1.9999956    , -1.9964080    ,  1.0000000    ,  .99645999    ,
@@ -489,7 +489,7 @@ void lpp_killdc( float *inbuf, int in_frames, int channels, t_bashfest *x)
     }
 }
 
-void lpp_set_dcflt(float *a)
+void lpp_set_dcflt(t_float *a)
 {
     a[0] = 3;
     a[1] = -1.9999924;
@@ -507,14 +507,14 @@ void lpp_set_dcflt(float *a)
     a[13] = 0.98817413;
 }
 
-void lpp_set_distortion_table(float *arr, float cut, float max, int len)
+void lpp_set_distortion_table(t_float *arr, t_float cut, t_float max, int len)
 {
     int i, len2;
-    float samp;
+    t_float samp;
     
     len2 = len>>1 ;
     for( i = len2; i < len; i++ ) {
-        samp = (float)(i - len2) / (float) len2 ;
+        samp = (t_float)(i - len2) / (t_float) len2 ;
         if( samp > cut )
             samp = lpp_mapp( samp, cut, 1.0,  cut, max );
         *(arr + i) = samp;
@@ -523,16 +523,16 @@ void lpp_set_distortion_table(float *arr, float cut, float max, int len)
     *(arr + i) = - *(arr + len - (i+1));
 }
 
-float lpp_dlookup(float samp,float *arr,int len)
+t_float lpp_dlookup(t_float samp,t_float *arr,int len)
 {
-    return arr[(int) (((samp+1.0)/2.0) * (float) len)];
+    return arr[(int) (((samp+1.0)/2.0) * (t_float) len)];
 }
 
-void lpp_do_compdist(float *in,float *out,int sampFrames,int nchans,int channel,
-                     float cutoff,float maxmult,int lookupflag,float *table,int range,float bufMaxamp)
+void lpp_do_compdist(t_float *in,t_float *out,int sampFrames,int nchans,int channel,
+                     t_float cutoff,t_float maxmult,int lookupflag,t_float *table,int range,t_float bufMaxamp)
 {
     int i;
-    float rectsamp;
+    t_float rectsamp;
     
     for( i = channel ; i < sampFrames * nchans; i+= nchans ) {
         if( lookupflag) {
@@ -547,10 +547,10 @@ void lpp_do_compdist(float *in,float *out,int sampFrames,int nchans,int channel,
     }
 }
 
-float lpp_getmaxamp(float *arr, int len)
+t_float lpp_getmaxamp(t_float *arr, int len)
 {
     int i;
-    float max = 0;
+    t_float max = 0;
     
     for(i = 0; i < len; i++ ) {
         if( fabs(arr[i]) > max )
@@ -561,22 +561,22 @@ float lpp_getmaxamp(float *arr, int len)
 
 void lpp_buildadsr(CMIXADSR *a)
 {
-    float A = a->a;
-    float D = a->d;
-    float S = a->s;
-    float R = a->r;
-    float f1 = a->v1;
-    float f2 = a->v2;
-    float f3 = a->v3;
-    float f4 = a->v4;
+    t_float A = a->a;
+    t_float D = a->d;
+    t_float S = a->s;
+    t_float R = a->r;
+    t_float f1 = a->v1;
+    t_float f2 = a->v2;
+    t_float f3 = a->v3;
+    t_float f4 = a->v4;
     
     int funclen = a->len;
-    float *func = a->func;
-    float total;
+    t_float *func = a->func;
+    t_float total;
     int ipoint = 0;
     int i;
     int segs[4];
-    float m1,m2;
+    t_float m1,m2;
     total = A + D + S + R ;
     
     segs[0] = (A/total) * funclen;
@@ -604,28 +604,28 @@ void lpp_buildadsr(CMIXADSR *a)
     }
     
     for( i = 0 ; i < segs[0]; i++ ) {
-        m1 = 1.-(float)i/(float)(segs[0]);
+        m1 = 1.-(t_float)i/(t_float)(segs[0]);
         m2 = 1. - m1;
         *(func +i ) = f1 * m1 + f2 * m2;
     }
     ipoint = i;
     
     for( i = 0 ; i < segs[1]; i++ ) {
-        m1 = 1.-(float)i/(float)(segs[1]);
+        m1 = 1.-(t_float)i/(t_float)(segs[1]);
         m2 = 1. - m1;
         *(func + i + ipoint) = f2 * m1 + f3 * m2;
     }
     ipoint += i;
     
     for( i = 0 ; i < segs[2]; i++ ) {
-        m1 = 1.-(float)i/(float)(segs[2]);
+        m1 = 1.-(t_float)i/(t_float)(segs[2]);
         m2 = 1. - m1;
         *(func + i + ipoint) = f3;
     }
     ipoint += i;
     
     for( i = 0 ; i < segs[3]; i++ ) {
-        m1 = 1.-(float)i/(float)(segs[3]);
+        m1 = 1.-(t_float)i/(t_float)(segs[3]);
         m2 = 1. - m1;
         *(func + ipoint + i) = f3 * m1 + f4 * m2;
     }
