@@ -10,15 +10,15 @@ static t_class *granule_class;
 
 
 typedef struct {
-  float amplitude;
-  float panL;
-  float panR;
+  t_float amplitude;
+  t_float panL;
+  t_float panR;
   long delay; // samples to wait until event starts
   long duration;// length in samples of event
-  float phase; // phase for frequency oscillator
-  float ephase; // phase for envelope
-  float si; // sampling increment for frequency
-  float esi; // sampling increment for envelope
+  t_float phase; // phase for frequency oscillator
+  t_float ephase; // phase for envelope
+  t_float si; // sampling increment for frequency
+  t_float esi; // sampling increment for envelope
 } t_grain;
 
 typedef struct {
@@ -32,37 +32,37 @@ typedef struct _granule
 {
 
   t_object x_obj;
-  float x_f;
+  t_float x_f;
   t_pdbuffer *wavebuf; // holds waveform samples
   t_pdbuffer *windowbuf; // holds window samples
   t_symbol *wavename; // name of waveform buffer
   t_symbol *windowname; // name of window buffer
 
-  float sr; // sampling rate
+  t_float sr; // sampling rate
   short mute;
   short hosed; // buffers are bad
   /* Global grain data*/
   long events; // number of events in a block
   long horizon; // length of block for random events
-  float minfreq; // minimum frequency for a grain
-  float maxfreq; // maximum frequency for a grain
-  float minpan; // minimum pan for a grain
-  float maxpan; // maximum pan for a grain
-  float minamp; // minimum amplitude for a grain
-  float maxamp; // maximum amplitude for a grain
-  float mindur; // minimum duration for a grain
-  float maxdur; // maximum duration for a grain
+  t_float minfreq; // minimum frequency for a grain
+  t_float maxfreq; // maximum frequency for a grain
+  t_float minpan; // minimum pan for a grain
+  t_float maxpan; // maximum pan for a grain
+  t_float minamp; // minimum amplitude for a grain
+  t_float maxamp; // maximum amplitude for a grain
+  t_float mindur; // minimum duration for a grain
+  t_float maxdur; // maximum duration for a grain
   t_grain *grains; // stores grain data
-  float *pitchscale; // contains a frequency grid for pitch constraint
+  t_float *pitchscale; // contains a frequency grid for pitch constraint
   int pitchsteps; // number of members in scale
-  float transpose; // factor for scaling all pitches
-  float pitch_deviation; // factor to adjust scaled pitches
+  t_float transpose; // factor for scaling all pitches
+  t_float pitch_deviation; // factor to adjust scaled pitches
   short steady; // toggles pulsed rhythmic activity
-  float lowblock_freq; //lowest allowed frequency
-  float highblock_freq;// highest allowed frequency
-  float mindur_ms;//store duration in ms
-  float maxdur_ms;//ditto
-  float horizon_ms;//ditto
+  t_float lowblock_freq; //lowest allowed frequency
+  t_float highblock_freq;// highest allowed frequency
+  t_float mindur_ms;//store duration in ms
+  t_float maxdur_ms;//ditto
+  t_float horizon_ms;//ditto
   short constrain_scale;//flag to only use bounded portion of scale rather than all of it
 } t_granule;
 
@@ -79,7 +79,7 @@ static void granule_pitchdev(t_granule *x, t_floatarg d);
 static void granule_lowblock(t_granule *x, t_floatarg f);
 static void granule_highblock(t_granule *x, t_floatarg f);
 static void granule_events(t_granule *x, t_floatarg e);
-static float granule_boundrand(float min, float max);
+static t_float granule_boundrand(t_float min, t_float max);
 static void *granule_grist(t_granule *x, t_symbol *msg, int argc, t_atom *argv);
 static void *granule_grain(t_granule *x, t_symbol *msg, int argc, t_atom *argv);
 static void *granule_setscale(t_granule *x, t_symbol *msg, int argc, t_atom *argv);
@@ -89,7 +89,7 @@ static void granule_steady(t_granule *x, t_floatarg toggle);
 static void granule_constrain_scale(t_granule *x, t_floatarg toggle);
 static void granule_dsp_free(t_granule *x);
 static void granule_init(t_granule *x,short initialized);
-static void granule_constrain(int *index_min, int *index_max, float minfreq, float maxfreq, float *scale, int steps);
+static void granule_constrain(int *index_min, int *index_max, t_float minfreq, t_float maxfreq, t_float *scale, int steps);
 
 void granule_tilde_setup(void) {
   granule_class = class_new(gensym("granule~"), (t_newmethod)granule_new,
@@ -158,7 +158,7 @@ void granule_events(t_granule *x, t_floatarg e)
     return;
   }
   x->events = e;
-  //  x->steady_dur = x->horizon / (float) x->events;
+  //  x->steady_dur = x->horizon / (t_float) x->events;
 }
 
 void granule_transpose(t_granule *x, t_floatarg t)
@@ -173,7 +173,7 @@ void granule_transpose(t_granule *x, t_floatarg t)
 void *granule_setscale(t_granule *x, t_symbol *msg, int argc, t_atom *argv)
 {
   int i;
-  float *pitchscale = x->pitchscale;
+  t_float *pitchscale = x->pitchscale;
   if( argc >= MAXSCALE ) {
     pd_error(0, "%d is the maximum size scale", MAXSCALE);
     return 0;
@@ -190,7 +190,7 @@ void *granule_setscale(t_granule *x, t_symbol *msg, int argc, t_atom *argv)
   return 0;
 }
 
-void granule_constrain(int *index_min, int *index_max, float minfreq, float maxfreq, float *scale, int steps)
+void granule_constrain(int *index_min, int *index_max, t_float minfreq, t_float maxfreq, t_float *scale, int steps)
 {
   int imax = steps - 1;
   int imin = 0;
@@ -222,28 +222,28 @@ void granule_pitchspray(t_granule *x)
 
   long eframes = x->windowbuf->b_frames;
   long frames = x->wavebuf->b_frames;
-  float sr = x->sr;
+  t_float sr = x->sr;
   long horizon = x->horizon; // length of block for random events
-  float mindur = x->mindur;
-  float maxdur = x->maxdur;
-  float minfreq = x->minfreq; // minimum frequency for a grain
-  float maxfreq = x->maxfreq; // maximum frequency for a grain
-  float minpan = x->minpan; // minimum pan for a grain
-  float maxpan = x->maxpan; // maximum pan for a grain
-  float minamp = x->minamp; // minimum amplitude for a grain
-  float maxamp = x->maxamp; // maximum amplitude for a grain
-  float transpose = x->transpose; // pitch scalar
-  float lowblock_freq = x->lowblock_freq;
-  float highblock_freq = x->highblock_freq;
+  t_float mindur = x->mindur;
+  t_float maxdur = x->maxdur;
+  t_float minfreq = x->minfreq; // minimum frequency for a grain
+  t_float maxfreq = x->maxfreq; // maximum frequency for a grain
+  t_float minpan = x->minpan; // minimum pan for a grain
+  t_float maxpan = x->maxpan; // maximum pan for a grain
+  t_float minamp = x->minamp; // minimum amplitude for a grain
+  t_float maxamp = x->maxamp; // maximum amplitude for a grain
+  t_float transpose = x->transpose; // pitch scalar
+  t_float lowblock_freq = x->lowblock_freq;
+  t_float highblock_freq = x->highblock_freq;
   short steady = x->steady;
-  float pitch_deviation = x->pitch_deviation;
-  float pdev = 0;
-  float pdev_invert = 0;
-  //  float pscale;
-  float pan;
+  t_float pitch_deviation = x->pitch_deviation;
+  t_float pdev = 0;
+  t_float pdev_invert = 0;
+  //  t_float pscale;
+  t_float pan;
   int index_min, index_max;
   int steps = x->pitchsteps;
-  float *scale = x->pitchscale;
+  t_float *scale = x->pitchscale;
   int windex;
   short inserted = 0;
   short constrain_scale = x->constrain_scale;
@@ -263,9 +263,9 @@ void granule_pitchspray(t_granule *x)
     for(j = 0; j < MAXGRAINS; j++ ) {
       if( grains[j].ephase >= eframes ) {
         if(steady) {
-          grains[j].delay = (float)(i * horizon) / (float) x->events ;
+          grains[j].delay = (t_float)(i * horizon) / (t_float) x->events ;
         } else {
-          grains[j].delay = granule_boundrand(0.0,(float) horizon);
+          grains[j].delay = granule_boundrand(0.0,(t_float) horizon);
         }
         grains[j].duration = (long) granule_boundrand(mindur, maxdur);
         grains[j].phase = 0.0;
@@ -274,14 +274,14 @@ void granule_pitchspray(t_granule *x)
         grains[j].panL = cos(pan * PIOVERTWO);
         grains[j].panR = sin(pan * PIOVERTWO);
         grains[j].amplitude = granule_boundrand(minamp, maxamp);
-        grains[j].esi =  (float) eframes / (float) grains[j].duration ;
+        grains[j].esi =  (t_float) eframes / (t_float) grains[j].duration ;
         if(constrain_scale) {
           granule_constrain(&index_min,&index_max,minfreq, maxfreq, scale, steps);
-          windex = (int) granule_boundrand((float)index_min, (float)index_max);
+          windex = (int) granule_boundrand((t_float)index_min, (t_float)index_max);
         } else {
-          windex = (int) granule_boundrand(0.0, (float)(steps-1));
+          windex = (int) granule_boundrand(0.0, (t_float)(steps-1));
         }
-        grains[j].si = transpose * scale[windex] * (float) frames / sr;
+        grains[j].si = transpose * scale[windex] * (t_float) frames / sr;
         if( pitch_deviation ) {
           grains[j].si *= granule_boundrand(pdev_invert,pdev);
         }
@@ -317,20 +317,20 @@ void granule_spray(t_granule *x)
   int i,j;
   long eframes = x->windowbuf->b_frames;
   long frames = x->wavebuf->b_frames;
-  float sr = x->sr;
+  t_float sr = x->sr;
   long horizon = x->horizon; // length of block for random events
-  float mindur = x->mindur;
-  float maxdur = x->maxdur;
-  float minfreq = x->minfreq; // minimum frequency for a grain
-  float maxfreq = x->maxfreq; // maximum frequency for a grain
-  float minpan = x->minpan; // minimum pan for a grain
-  float maxpan = x->maxpan; // maximum pan for a grain
-  float minamp = x->minamp; // minimum amplitude for a grain
-  float maxamp = x->maxamp; // maximum amplitude for a grain
-  float transpose = x->transpose; // pitch scalar
-  //  float steady_dur = x->steady_dur;
+  t_float mindur = x->mindur;
+  t_float maxdur = x->maxdur;
+  t_float minfreq = x->minfreq; // minimum frequency for a grain
+  t_float maxfreq = x->maxfreq; // maximum frequency for a grain
+  t_float minpan = x->minpan; // minimum pan for a grain
+  t_float maxpan = x->maxpan; // maximum pan for a grain
+  t_float minamp = x->minamp; // minimum amplitude for a grain
+  t_float maxamp = x->maxamp; // maximum amplitude for a grain
+  t_float transpose = x->transpose; // pitch scalar
+  //  t_float steady_dur = x->steady_dur;
   short steady = x->steady;
-  float pan;
+  t_float pan;
   t_grain *grains = x->grains;
   short inserted;
 
@@ -339,9 +339,9 @@ void granule_spray(t_granule *x)
     for(j = 0; j < MAXGRAINS; j++ ) {
       if( grains[j].ephase >= eframes ) {
         if(steady) {
-          grains[j].delay = (float)(i * horizon) / (float) x->events ;
+          grains[j].delay = (t_float)(i * horizon) / (t_float) x->events ;
         } else {
-          grains[j].delay = granule_boundrand(0.0,(float) horizon);
+          grains[j].delay = granule_boundrand(0.0,(t_float) horizon);
         }
         grains[j].duration = (long) granule_boundrand(mindur, maxdur);
         grains[j].phase = 0.0;
@@ -350,8 +350,8 @@ void granule_spray(t_granule *x)
         grains[j].panL = cos(pan * PIOVERTWO);
         grains[j].panR = sin(pan * PIOVERTWO);
         grains[j].amplitude = granule_boundrand(minamp, maxamp);
-        grains[j].esi =  (float) eframes / (float) grains[j].duration ;
-        grains[j].si = transpose * granule_boundrand(minfreq, maxfreq) * (float) frames / sr;
+        grains[j].esi =  (t_float) eframes / (t_float) grains[j].duration ;
+        grains[j].si = transpose * granule_boundrand(minfreq, maxfreq) * (t_float) frames / sr;
         inserted = 1;
         goto nextgrain;
       }
@@ -368,11 +368,11 @@ void *granule_grain(t_granule *x, t_symbol *msg, int argc, t_atom *argv)
 {
   short inserted;
   int j;
-  float duration, frequency, amplitude, pan;
+  t_float duration, frequency, amplitude, pan;
   t_grain *grains;
   long eframes;
   long frames;
-  float sr;
+  t_float sr;
 
   grains = x->grains;
   eframes = x->windowbuf->b_frames;
@@ -410,8 +410,8 @@ void *granule_grain(t_granule *x, t_symbol *msg, int argc, t_atom *argv)
       grains[j].panL = cos(pan * PIOVERTWO);
       grains[j].panR = sin(pan * PIOVERTWO);
       grains[j].amplitude = amplitude;
-      grains[j].esi =  (float) eframes / (float) grains[j].duration ;
-      grains[j].si = frequency * (float) frames / sr;
+      grains[j].esi =  (t_float) eframes / (t_float) grains[j].duration ;
+      grains[j].si = frequency * (t_float) frames / sr;
       return 0;
     }
   }
@@ -421,9 +421,9 @@ void *granule_grain(t_granule *x, t_symbol *msg, int argc, t_atom *argv)
 
 }
 
-float granule_boundrand(float min, float max)
+t_float granule_boundrand(t_float min, t_float max)
 {
-  return min + (max-min) * ((float) (rand() % RAND_MAX)/ (float) RAND_MAX);
+  return min + (max-min) * ((t_float) (rand() % RAND_MAX)/ (t_float) RAND_MAX);
 }
 
 
@@ -437,7 +437,7 @@ void *granule_new(t_symbol *msg, int argc, t_atom *argv)
   x->windowbuf = (t_pdbuffer*)getbytes(sizeof(t_pdbuffer));
   srand(time(0));
 
-  x->pitchscale = (float *) getbytes(MAXSCALE * sizeof(float));
+  x->pitchscale = (t_float *) getbytes(MAXSCALE * sizeof(t_float));
   x->grains = (t_grain *) getbytes(MAXGRAINS * sizeof(t_grain));
 
 
@@ -601,8 +601,8 @@ void granule_setbuf(t_granule *x, t_symbol *wavename, t_symbol *windowname)
 t_int *granule_performhose(t_int *w)
 {
   //  t_granule *x = (t_granule *) (w[1]);
-  float *outputL = (t_float *)(w[3]);
-  float *outputR = (t_float *)(w[4]);
+  t_float *outputL = (t_float *)(w[3]);
+  t_float *outputR = (t_float *)(w[4]);
   int n = (int) w[5];
   while(n--) *outputL++ = *outputR++ = 0;
   return (w+6);
@@ -611,9 +611,9 @@ t_int *granule_performhose(t_int *w)
 t_int *granule_perform(t_int *w)
 {
   t_granule *x = (t_granule *) (w[1]);
-  //  float *in = (t_float *)(w[2]); // ignoring input
-  float *outputL = (t_float *)(w[3]);
-  float *outputR = (t_float *)(w[4]);
+  //  t_float *in = (t_float *)(w[2]); // ignoring input
+  t_float *outputL = (t_float *)(w[3]);
+  t_float *outputR = (t_float *)(w[4]);
   int n = (int) w[5];
 
   t_pdbuffer *wavebuf = x->wavebuf;
@@ -621,14 +621,14 @@ t_int *granule_perform(t_int *w)
   t_word *wavetable = wavebuf->b_samples;
   t_word *window = windowbuf->b_samples;
   t_grain *grains = x->grains;
-  float sample;
-  float envelope;
-  float amplitude;
-  float panL, panR;
-  float si;
-  float esi;
-  float phase;
-  float ephase;
+  t_float sample;
+  t_float envelope;
+  t_float amplitude;
+  t_float panL, panR;
+  t_float si;
+  t_float esi;
+  t_float phase;
+  t_float ephase;
   long delay;
   long frames = wavebuf->b_frames;
   long eframes = windowbuf->b_frames;
@@ -704,7 +704,7 @@ void granule_dsp_free(t_granule *x)
 {
 
   freebytes(x->grains, MAXGRAINS * sizeof(t_grain));
-  freebytes(x->pitchscale, MAXSCALE * sizeof(float));
+  freebytes(x->pitchscale, MAXSCALE * sizeof(t_float));
 }
 
 void granule_dsp(t_granule *x, t_signal **sp)
